Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `spoon`
  - `messaging`
  - `NullLogger`

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `spoon.NullLogger.NullLogger`: Dummy logging object.
  - `None.Serial`
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
    - `None.SerialMeta`
- `exceptions.Exception`: Common base class for all exceptions.

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net